about summary refs log tree commit diff
path: root/nixos/lib/make-iso9660-image.nix
diff options
context:
space:
mode:
authorPavol Rusnak <pavol@rusnak.io>2020-04-24 18:12:42 +0200
committerPavol Rusnak <pavol@rusnak.io>2020-04-24 18:34:11 +0200
commitf20fd89fc02454f41ec4844c3ddf03b7edbe2639 (patch)
tree5bbc7548bf09a0d5501d0fe0d7f05b7b31ec15a0 /nixos/lib/make-iso9660-image.nix
parentc09ffc7a5584ac3f9fbf0cee3e0e6f6596a6ed37 (diff)
iso-image: use zstd for compression
Diffstat (limited to 'nixos/lib/make-iso9660-image.nix')
-rw-r--r--nixos/lib/make-iso9660-image.nix4
1 files changed, 2 insertions, 2 deletions
diff --git a/nixos/lib/make-iso9660-image.nix b/nixos/lib/make-iso9660-image.nix
index 0f3f2b5b5234d..be8ad9912db09 100644
--- a/nixos/lib/make-iso9660-image.nix
+++ b/nixos/lib/make-iso9660-image.nix
@@ -34,7 +34,7 @@
 , # The path (outside the ISO file system) of the isohybrid-mbr image.
   isohybridMbrImage ? ""
 
-, # Whether to compress the resulting ISO image with bzip2.
+, # Whether to compress the resulting ISO image with zstd.
   compressImage ? false
 
 , # The volume ID.
@@ -48,7 +48,7 @@ assert usbBootable -> isohybridMbrImage != "";
 stdenv.mkDerivation {
   name = isoName;
   builder = ./make-iso9660-image.sh;
-  buildInputs = [ xorriso syslinux ];
+  buildInputs = [ xorriso syslinux zstd ];
 
   inherit isoName bootable bootImage compressImage volumeID efiBootImage efiBootable isohybridMbrImage usbBootable;